@@ -13,25 +13,31 @@
 #'   by any of those methods, whichever succeeds. See 'Details'.
 #' @param ... Currently not used.
 #'
-#' @details Methods for calculating degrees of freedom:
-#' \itemize{
-#' \item `"analytical"` for models of class `lmerMod`, Kenward-Roger approximated degrees of freedoms are calculated, for other models, `n-k` (number of observations minus number of parameters).
-#' \item `"residual"` tries to extract residual degrees of freedom, and returns `Inf` if residual degrees of freedom could not be extracted.
-#' \item `"any"` first tries to extract residual degrees of freedom, and if these are not available, extracts analytical degrees of freedom.
-#' \item `"nokr"` same as `"analytical"`, but does not Kenward-Roger approximation for models of class `lmerMod`. Instead, always uses `n-k` to calculate df for any model.
-#' \item `"normal"` returns `Inf`.
-#' \item `"wald"` returns residual df for models with t-statistic, and `Inf` for all other models.
-#' \item `"kenward"` calls [`dof_kenward()`].
-#' \item `"satterthwaite"` calls [`dof_satterthwaite()`].
-#' \item `"ml1"` calls [`dof_ml1()`].
-#' \item `"betwithin"` calls [`dof_betwithin()`].
-#' }
+#' @details
+#' Methods for calculating degrees of freedom:
+#'
+#' - `"analytical"` for models of class `lmerMod`, Kenward-Roger approximated
+#'   degrees of freedoms are calculated, for other models, `n-k` (number of
+#'   observations minus number of parameters).
+#' - `"residual"` tries to extract residual degrees of freedom, and returns
+#'   `Inf` if residual degrees of freedom could not be extracted.
+#' - `"any"` first tries to extract residual degrees of freedom, and if these
+#'   are not available, extracts analytical degrees of freedom.
+#' - `"nokr"` same as `"analytical"`, but does not Kenward-Roger approximation
+#'   for models of class `lmerMod`. Instead, always uses `n-k` to calculate df
+#'   for any model.
+#' - `"normal"` returns `Inf`.
+#' - `"wald"` returns residual df for models with t-statistic, and `Inf` for all other models.
+#' - `"kenward"` calls [`dof_kenward()`].
+#' - `"satterthwaite"` calls [`dof_satterthwaite()`].
+#' - `"ml1"` calls [`dof_ml1()`].
+#' - `"betwithin"` calls [`dof_betwithin()`].
+#'
 #' For models with z-statistic, the returned degrees of freedom for model parameters
 #' is `Inf` (unless `method = "ml1"` or `method = "betwithin"`), because there is
 #' only one distribution for the related test statistic.
 #'
 #' @note
-#'
 #' In many cases, `degrees_of_freedom()` returns the same as `df.residuals()`,
 #' or `n-k` (number of observations minus number of parameters). However,
 #' `degrees_of_freedom()` refers to the model's *parameters* degrees of freedom
@@ -138,7 +144,7 @@ degrees_of_freedom.default <- function(model, method = "analytical", ...) {
   }
 
   if (!is.null(dof) && length(dof) > 0 && all(dof == 0)) {
-    warning("Model has zero degrees of freedom!", call. = FALSE)
+    insight::format_warning("Model has zero degrees of freedom!")
   }
 
   dof
@@ -203,7 +209,7 @@ dof <- degrees_of_freedom
   if (inherits(dof, "try-error") || is.null(dof) || all(is.na(dof))) {
     dof <- Inf
     if (verbose) {
-      warning("Could not extract degrees of freedom.", call. = FALSE)
+      insight::format_alert("Could not extract degrees of freedom.")
     }
   }
 
@@ -261,6 +267,8 @@ dof <- degrees_of_freedom
   }
 
   method <- tolower(method)
+
+  # exceptions 1
   if (inherits(model, c("polr", "glm", "svyglm"))) {
     if (method %in% c(
       "analytical", "any", "fit", "profile", "residual",
@@ -269,7 +277,19 @@ dof <- degrees_of_freedom
       return(TRUE)
     } else {
       if (verbose) {
-        insight::format_warning(sprintf("`%s` must be one of \"wald\", \"residual\" or \"profile\". Using \"wald\" now.", type))
+        insight::format_alert(sprintf("`%s` must be one of \"wald\", \"residual\" or \"profile\". Using \"wald\" now.", type))
+      }
+      return(FALSE)
+    }
+  }
+
+  # exceptions 2
+  if (inherits(model, c("phylolm", "phyloglm"))) {
+    if (method %in% c("analytical", "any", "fit", "residual", "wald", "nokr", "normal", "boot")) {
+      return(TRUE)
+    } else {
+      if (verbose) {
+        insight::format_alert(sprintf("`%s` must be one of \"wald\", \"normal\" or \"boot\". Using \"wald\" now.", type))
       }
       return(FALSE)
     }
@@ -278,7 +298,7 @@ dof <- degrees_of_freedom
   info <- insight::model_info(model, verbose = FALSE)
   if (!is.null(info) && isFALSE(info$is_mixed) && method == "boot") {
     if (verbose) {
-      insight::format_warning(sprintf("`%s=boot` only works for mixed models of class `merMod`. To bootstrap this model, use `bootstrap=TRUE, ci_method=\"bcai\"`.", type))
+      insight::format_alert(sprintf("`%s=boot` only works for mixed models of class `merMod`. To bootstrap this model, use `bootstrap=TRUE, ci_method=\"bcai\"`.", type))
     }
     return(TRUE)
   }
@@ -286,7 +306,7 @@ dof <- degrees_of_freedom
   if (is.null(info) || !info$is_mixed) {
     if (!(method %in% c("analytical", "any", "fit", "betwithin", "nokr", "wald", "ml1", "profile", "boot", "uniroot", "residual", "normal"))) {
       if (verbose) {
-        insight::format_warning(sprintf("`%s` must be one of \"residual\", \"wald\", \"normal\", \"profile\", \"boot\", \"uniroot\", \"betwithin\" or \"ml1\". Using \"wald\" now.", type))
+        insight::format_alert(sprintf("`%s` must be one of \"residual\", \"wald\", \"normal\", \"profile\", \"boot\", \"uniroot\", \"betwithin\" or \"ml1\". Using \"wald\" now.", type))
       }
       return(FALSE)
     }
@@ -295,14 +315,14 @@ dof <- degrees_of_freedom
 
   if (!(method %in% c("analytical", "any", "fit", "satterthwaite", "betwithin", "kenward", "kr", "nokr", "wald", "ml1", "profile", "boot", "uniroot", "residual", "normal"))) {
     if (verbose) {
-      insight::format_warning(sprintf("`%s` must be one of \"residual\", \"wald\", \"normal\", \"profile\", \"boot\", \"uniroot\", \"kenward\", \"satterthwaite\", \"betwithin\" or \"ml1\". Using \"wald\" now.", type))
+      insight::format_alert(sprintf("`%s` must be one of \"residual\", \"wald\", \"normal\", \"profile\", \"boot\", \"uniroot\", \"kenward\", \"satterthwaite\", \"betwithin\" or \"ml1\". Using \"wald\" now.", type))
     }
     return(FALSE)
   }
 
   if (!info$is_linear && method %in% c("satterthwaite", "kenward", "kr")) {
     if (verbose) {
-      insight::format_warning(sprintf("`%s`-degrees of freedoms are only available for linear mixed models.", method))
+      insight::format_alert(sprintf("`%s`-degrees of freedoms are only available for linear mixed models.", method))
     }
     return(FALSE)
   }
