@@ -74,6 +74,14 @@ format.parameters_model <- function(x,
     x$Response <- NULL
   }
 
+  # remove component for nestedLogit
+  if (!is.null(m_class) && any(m_class == "nestedLogit")) {
+    x$Component <- NULL
+    if (insight::n_unique(x$Response) == 1) {
+      x$Response <- NULL
+    }
+  }
+
   # remove type for comparisons()
   if (!is.null(m_class) && any(m_class == "comparisons")) {
     x$Type <- NULL
