@@ -42,7 +42,9 @@ model_parameters.stanfit <- function(model,
     random_effect_levels <- which(
       params$Effects %in% "random" & !startsWith(params$Parameter, "Sigma[")
     )
-    if (length(random_effect_levels) && isFALSE(group_level)) params <- params[-random_effect_levels, ]
+    if (length(random_effect_levels) && isFALSE(group_level)) {
+      params <- params[-random_effect_levels, ]
+    }
   }
 
   # exponentiate coefficients and SE/CI, if requested
@@ -60,7 +62,7 @@ model_parameters.stanfit <- function(model,
 
   attr(params, "parameter_info") <- insight::clean_parameters(model)
   attr(params, "object_name") <- insight::safe_deparse_symbol(substitute(model))
-  class(params) <- c("parameters_stan", "parameters_model", "see_parameters_model", class(params))
+  class(params) <- c("parameters_model", "see_parameters_model", class(params))
 
   params
 }
